==> qtjambi-qt3dcore-5.15.13-sources.jar: io/qt/qt3d/core/QComponentAddedChange.java <==
package io.qt.qt3d.core;


/**
 * <p>Used to notify when a component is added to an entity</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html">Qt3DCore::QComponentAddedChange</a></p>
 */
public class QComponentAddedChange extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#QComponentAddedChange-1">Qt3DCore::QComponentAddedChange::QComponentAddedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)</a></p>
     */
    @Deprecated
    public QComponentAddedChange(io.qt.qt3d.core.QComponent component, io.qt.qt3d.core.QEntity entity){
        super((QPrivateConstructor)null);
        initialize_native(this, component, entity);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentAddedChange instance, io.qt.qt3d.core.QComponent component, io.qt.qt3d.core.QEntity entity);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#QComponentAddedChange">Qt3DCore::QComponentAddedChange::QComponentAddedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)</a></p>
     */
    @Deprecated
    public QComponentAddedChange(io.qt.qt3d.core.QEntity entity, io.qt.qt3d.core.QComponent component){
        super((QPrivateConstructor)null);
        initialize_native(this, entity, component);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentAddedChange instance, io.qt.qt3d.core.QEntity entity, io.qt.qt3d.core.QComponent component);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#componentId">Qt3DCore::QComponentAddedChange::componentId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId componentId(){
        return componentId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId componentId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#componentMetaObject">Qt3DCore::QComponentAddedChange::componentMetaObject()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QMetaObject componentMetaObject(){
        return componentMetaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QMetaObject componentMetaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#entityId">Qt3DCore::QComponentAddedChange::entityId()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId entityId(){
        return entityId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId entityId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QComponentAddedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QComponentAddedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a component is added to an entity</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html">Qt3DCore::QComponentAddedChange</a></p>
 */
public class QComponentAddedChange extends io.qt.qt3d.core.QSceneChange
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#QComponentAddedChange-1">Qt3DCore::QComponentAddedChange::QComponentAddedChange(const Qt3DCore::QComponent*,const Qt3DCore::QEntity*)</a></p>
     */
    @Deprecated
    public QComponentAddedChange(io.qt.qt3d.core.@Nullable QComponent component, io.qt.qt3d.core.@Nullable QEntity entity){
        super((QPrivateConstructor)null);
        initialize_native(this, component, entity);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentAddedChange instance, io.qt.qt3d.core.QComponent component, io.qt.qt3d.core.QEntity entity);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#QComponentAddedChange">Qt3DCore::QComponentAddedChange::QComponentAddedChange(const Qt3DCore::QEntity*,const Qt3DCore::QComponent*)</a></p>
     */
    @Deprecated
    public QComponentAddedChange(io.qt.qt3d.core.@Nullable QEntity entity, io.qt.qt3d.core.@Nullable QComponent component){
        super((QPrivateConstructor)null);
        initialize_native(this, entity, component);
    }
    
    @Deprecated
    private native static void initialize_native(QComponentAddedChange instance, io.qt.qt3d.core.QEntity entity, io.qt.qt3d.core.QComponent component);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#componentId">Qt3DCore::QComponentAddedChange::componentId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId componentId(){
        return componentId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId componentId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#componentMetaObject">Qt3DCore::QComponentAddedChange::componentMetaObject()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject componentMetaObject(){
        return componentMetaObject_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject componentMetaObject_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qcomponentaddedchange.html#entityId">Qt3DCore::QComponentAddedChange::entityId()const</a></p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId entityId(){
        return entityId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId entityId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QComponentAddedChange(QPrivateConstructor p) { super(p); } 
    
}
